==> react-bootstrap-design-0.12.0.tgz: package/src/configurations/models/SmallSecondsSquare.js <==
var AllStyles = require('../AllStyles');

var SmallSecondsSquare = {
    case: {
        shape: AllStyles.shape.rounded,
        bg: AllStyles.background.steel,
    },
    color: AllStyles.color.white,
    dial: {
        shape: AllStyles.shape.rounded,
        bg: {
            color: AllStyles.background.greyFume,
            pattern: {
                type: 'burst',
                opacity: .05
            }
        }
    },
    hands: {
        type: {
            hour: 'hour',
            minute: 'minute'
        },
        hour: {
            color: AllStyles.background.success,
            length: '30%',
            margin: '0 20%',
            width: '4px'
        },
        minute: {
            color: AllStyles.background.primary
        }
    },
    header: 'London',
    index: {
        color: AllStyles.background.primary,
        nodeCount: AllStyles.index.type.hour,
        customNode: {
            6: {
                display: AllStyles.display.none
            },
            12: {
                display: AllStyles.display.none
            }
        }
    },
    grid: {
        2: {
            label: {
                color: AllStyles.color.grayLighter,
                font: AllStyles.font.tangerine,
                text: 'ABC'
            }
        },
        8: {
            dial: {
                border: 'solid black 1px',
                shape: AllStyles.shape.roundedCircle,
                bg: AllStyles.background.faded
            },
            index: {
                color: AllStyles.background.inverse,
                nodeCount: AllStyles.index.type.hour
            },
            hand: {
                type: 'second',
                color: AllStyles.background.primary
            },
        }
    },
    timeZone: 1
}

module.exports = SmallSecondsSquare;

==> react-bootstrap-design-0.13.0.tgz: package/src/configurations/models/SmallSecondsSquare.js <==
var AllStyles = require('../AllStyles');

var SmallSecondsSquare = {
    case: {
        shape: AllStyles.shape.rounded,
        bg: AllStyles.background.steel,
    },
    color: AllStyles.color.white,
    dial: {
        shape: AllStyles.shape.rounded,
        bg: {
            color: AllStyles.background.greyFume,
            pattern: {
                type: 'burst',
                opacity: .05
            }
        }
    },
    hands: {
        1: {
            type: 'hour',
            styles: {
                color: '#94c11c',
                height: '4px',
                margin: '0 20%',
                width: '30%'
            }
        },
        2: {
            type: 'minute',
            styles: {
                color: '#006b94'
            }
        }
    },
    header: 'London',
    index: {
        color: AllStyles.background.primary,
        nodeCount: AllStyles.index.type.hour,
        customNode: {
            6: {
                display: AllStyles.display.none
            },
            12: {
                display: AllStyles.display.none
            }
        }
    },
    grid: {
        2: {
            label: {
                color: AllStyles.color.grayLighter,
                font: AllStyles.font.tangerine,
                text: 'ABC'
            }
        },
        8: {
            dial: {
                border: 'solid black 1px',
                shape: AllStyles.shape.roundedCircle,
                bg: {
                    color: AllStyles.background.faded,
                    pattern: {
                        type: 'burst',
                        opacity: .10
                    }
                }
            },
            index: {
                color: AllStyles.background.inverse,
                nodeCount: AllStyles.index.type.hour
            },
            hands: {
                1: {
                    type: 'second',
                    styles: {
                        color: '#006b94'
                    }
                }
            }
        }
    },
    timeZone: 1
}

module.exports = SmallSecondsSquare;
